@@ -2,7 +2,7 @@
 
 import numpy as np
 import sys
-import test_numpy_setuptools_multi
+from .test_numpy_setuptools_multi import *
 
 def func(a, b):
     say_hello(a)
