@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
 
 def multiplication(a,b):
-	return a*b
\ No newline at end of file
+	return a*b
+
+if __name__ == '__main__':
+	pass
\ No newline at end of file
